@@ -233,6 +233,9 @@ TSPRegistryMapping = json.loads(
   "630": "TSA.InducedVerifyTransformHistoryWithServerCommandArchive",
   "631": "TSA.CommandReapplyMasterArchive",
   "632": "TSA.PropagateMasterChangeCommandArchive",
+  "633": "TSA.CaptionInfoArchive",
+  "634": "TSA.CaptionPlacementArchive",
+  "635": "TSA.TitlePlacementCommandArchive",
   "2001": "TSWP.StorageArchive",
   "2002": "TSWP.SelectionArchive",
   "2003": "TSWP.DrawableAttachmentArchive",
@@ -375,6 +378,10 @@ TSPRegistryMapping = json.loads(
   "3091": "TSD.FreehandDrawingToolkitUIState",
   "3092": "TSD.PencilAnnotationSelectionTransformerArchive",
   "3094": "TSD.FreehandDrawingAnimationCommandArchive",
+  "3095": "TSD.InsertCaptionOrTitleCommandArchive",
+  "3096": "TSD.RemoveCaptionOrTitleCommandArchive",
+  "3097": "TSD.StandinCaptionArchive",
+  "3098": "TSD.SetCaptionOrTitleVisibilityCommandArchive",
   "4000": "TSCE.CalculationEngineArchive",
   "4001": "TSCE.FormulaRewriteCommandArchive",
   "4002": "TSCE.TrackedReferencesRewriteCommandArchive",
